@@ -1,17 +1,19 @@
 """
 Drawing and plotting routines for IGraph.
 
-Plotting is dependent on the C{pycairo} library which provides Python bindings
-to the popular U{Cairo library<http://www.cairographics.org>}. This means that
-if you don't have U{pycairo<http://www.cairographics.org/pycairo>} installed,
-you won't be able to use the plotting capabilities. However, you can still use
-L{Graph.write_svg} to save the graph to an SVG file and view it from
+Plotting is dependent on the C{pycairo} or C{cairocffi} libraries that provide
+Python bindings to the popular U{Cairo library<http://www.cairographics.org>}.
+This means that if you don't have U{pycairo<http://www.cairographics.org/pycairo>}
+or U{cairocffi<http://cairocffi.readthedocs.io>} installed, you won't be able
+to use the plotting capabilities. However, you can still use L{Graph.write_svg}
+to save the graph to an SVG file and view it from
 U{Mozilla Firefox<http://www.mozilla.org/firefox>} (free) or edit it in
 U{Inkscape<http://www.inkscape.org>} (free), U{Skencil<http://www.skencil.org>}
-(formerly known as Sketch, also free) or Adobe Illustrator (not free, therefore
-I'm not linking to it :)).
-"""
+(formerly known as Sketch, also free) or Adobe Illustrator.
 
+Whenever the documentation refers to the C{pycairo} library, you can safely
+replace it with C{cairocffi} as the two are API-compatible.
+"""
 
 
 from io import StringIO
@@ -21,14 +23,20 @@ import os
 import platform
 import time
 
-from igraph.compat import property, BytesIO
+from io import BytesIO
 from igraph.configuration import Configuration
 from igraph.drawing.colors import Palette, palettes
-from igraph.drawing.graph import DefaultGraphDrawer
-from igraph.drawing.utils import BoundingBox, Point, Rectangle, find_cairo
+from igraph.drawing.graph import DefaultGraphDrawer, MatplotlibGraphDrawer
+from igraph.drawing.utils import (
+    BoundingBox,
+    Point,
+    Rectangle,
+    find_cairo,
+    find_matplotlib,
+)
 from igraph.utils import _is_running_in_ipython, named_temporary_file
 
-__all__ = ["BoundingBox", "DefaultGraphDrawer", "Plot", "Point", "Rectangle", "plot"]
+__all__ = ("BoundingBox", "DefaultGraphDrawer", "Plot", "Point", "Rectangle", "plot")
 
 __license__ = "GPL"
 
@@ -36,6 +44,7 @@ cairo = find_cairo()
 
 #####################################################################
 
+
 class Plot(object):
     """Class representing an arbitrary plot
 
@@ -47,7 +56,7 @@ class Plot(object):
     since C{pycairo} takes care of the actual drawing. Everything that's supported
     by C{pycairo} should be supported by this class as well.
 
-    Current Cairo surfaces that I'm aware of are:
+    Current Cairo surfaces include:
 
       - C{cairo.GlitzSurface} -- OpenGL accelerated surface for the X11
         Window System.
@@ -137,8 +146,9 @@ class Plot(object):
 
         if target is None:
             self._need_tmpfile = True
-            self._surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, \
-                int(self.bbox.width), int(self.bbox.height))
+            self._surface = cairo.ImageSurface(
+                cairo.FORMAT_ARGB32, int(self.bbox.width), int(self.bbox.height)
+            )
         elif isinstance(target, cairo.Surface):
             self._surface = target
         else:
@@ -146,17 +156,21 @@ class Plot(object):
             _, ext = os.path.splitext(target)
             ext = ext.lower()
             if ext == ".pdf":
-                self._surface = cairo.PDFSurface(target, self.bbox.width, \
-                                                 self.bbox.height)
+                self._surface = cairo.PDFSurface(
+                    target, self.bbox.width, self.bbox.height
+                )
             elif ext == ".ps" or ext == ".eps":
-                self._surface = cairo.PSSurface(target, self.bbox.width, \
-                                                self.bbox.height)
+                self._surface = cairo.PSSurface(
+                    target, self.bbox.width, self.bbox.height
+                )
             elif ext == ".png":
-                self._surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, \
-                    int(self.bbox.width), int(self.bbox.height))
+                self._surface = cairo.ImageSurface(
+                    cairo.FORMAT_ARGB32, int(self.bbox.width), int(self.bbox.height)
+                )
             elif ext == ".svg":
-                self._surface = cairo.SVGSurface(target, self.bbox.width, \
-                                                 self.bbox.height)
+                self._surface = cairo.SVGSurface(
+                    target, self.bbox.width, self.bbox.height
+                )
             else:
                 raise ValueError("image format not handled by Cairo: %s" % ext)
 
@@ -207,7 +221,7 @@ class Plot(object):
         """Sets the background color of the plot. C{None} means a
         transparent background. You can use any color specification here
         that is understood by the C{get} method of the current palette
-        or by L{igraph.colors.color_name_to_rgb}.
+        or by L{igraph.drawing.colors.color_name_to_rgb}.
         """
         if color is None:
             self._background = None
@@ -236,7 +250,7 @@ class Plot(object):
             if current_obj is obj and (bbox is None or current_bbox == bbox):
                 idx -= 1
                 if idx == 0:
-                    self._objects[i:(i+1)] = []
+                    self._objects[i : (i + 1)] = []
                     self.mark_dirty()
                     return True
         return False
@@ -260,7 +274,7 @@ class Plot(object):
                 palette = getattr(obj, "_default_palette", self._palette)
             plotter = getattr(obj, "__plot__", None)
             if plotter is None:
-                warn("%s does not support plotting" % obj)
+                warn("%s does not support plotting" % (obj,))
             else:
                 if opacity < 1.0:
                     ctx.push_group()
@@ -289,10 +303,11 @@ class Plot(object):
                     self._surface.write_to_png(fname)
                     return None
 
-            fname  = fname or self._filename
+            fname = fname or self._filename
             if fname is None:
-                raise ValueError("no file name is known for the surface " + \
-                                 "and none given")
+                raise ValueError(
+                    "no file name is known for the surface " + "and none given"
+                )
             return self._surface.write_to_png(fname)
 
         if fname is not None:
@@ -301,12 +316,21 @@ class Plot(object):
         self._ctx.show_page()
         self._surface.finish()
 
-
     def show(self):
-        """Saves the plot to a temporary file and shows it."""
+        """Saves the plot to a temporary file and shows it.
+
+        This method is deprecated from python-igraph 0.9.1 and will be removed in
+        version 0.10.0.
+
+        @deprecated: Opening an image viewer with a temporary file never worked
+            reliably across platforms.
+        """
+        warn("Plot.show() is deprecated from python-igraph 0.9.1", DeprecationWarning)
+
         if not isinstance(self._surface, cairo.ImageSurface):
-            sur = cairo.ImageSurface(cairo.FORMAT_ARGB32,
-                    int(self.bbox.width), int(self.bbox.height))
+            sur = cairo.ImageSurface(
+                cairo.FORMAT_ARGB32, int(self.bbox.width), int(self.bbox.height)
+            )
             ctx = cairo.Context(sur)
             self.redraw(ctx)
         else:
@@ -323,8 +347,9 @@ class Plot(object):
                 # No image viewer was given and none was detected. This
                 # should only happen on unknown platforms.
                 plat = platform.system()
-                raise NotImplementedError("showing plots is not implemented " + \
-                                          "on this platform: %s" % plat)
+                raise NotImplementedError(
+                    "showing plots is not implemented on this platform: %s" % plat
+                )
             else:
                 os.system("%s %s" % (imgviewer, tmpfile))
                 if platform.system() == "Darwin" or self._windows_hacks:
@@ -351,7 +376,13 @@ class Plot(object):
         context.show_page()
         surface.finish()
         # Return the raw SVG representation
-        return io.getvalue().encode("utf-8")
+        result = io.getvalue()
+        if hasattr(result, "encode"):
+            result = result.encode("utf-8")  # for Python 2.x
+        else:
+            result = result.decode("utf-8")  # for Python 3.x
+
+        return result, {"isolated": True}  # put it inside an iframe
 
     @property
     def bounding_box(self):
@@ -376,8 +407,10 @@ class Plot(object):
         is drawn"""
         return self.bbox.width
 
+
 #####################################################################
 
+
 def plot(obj, target=None, bbox=(0, 0, 600, 600), *args, **kwds):
     """Plots the given object to the given target.
 
@@ -390,16 +423,18 @@ def plot(obj, target=None, bbox=(0, 0, 600, 600), *args, **kwds):
     @param target: the target where the object should be plotted. It can be one
       of the following types:
 
-        - C{None} -- an appropriate surface will be created and the object will
-          be plotted there.
+        - C{string} -- a file with the given name will be created and an
+          appropriate Cairo surface will be attached to it. The supported image
+          formats are: PNG, PDF, SVG and PostScript.
 
         - C{cairo.Surface} -- the given Cairo surface will be used. This can
           refer to a PNG image, an arbitrary window, an SVG file, anything that
           Cairo can handle.
 
-        - C{string} -- a file with the given name will be created and an
-          appropriate Cairo surface will be attached to it. The supported image
-          formats are: PNG, PDF, SVG and PostScript.
+        - C{None} -- a temporary file will be created and the object will be
+          plotted there. igraph will attempt to open an image viewer and show
+          the temporary file. This feature is deprecated from python-igraph
+          version 0.9.1 and will be removed in 0.10.0.
 
     @param bbox: the bounding box of the plot. It must be a tuple with either
       two or four integers, or a L{BoundingBox} object. If this is a tuple
@@ -440,6 +475,13 @@ def plot(obj, target=None, bbox=(0, 0, 600, 600), *args, **kwds):
 
     @see: Graph.__plot__
     """
+    _, plt = find_matplotlib()
+
+    if hasattr(plt, "Axes") and isinstance(target, plt.Axes):
+        result = MatplotlibGraphDrawer(ax=target)
+        result.draw(obj, *args, **kwds)
+        return
+
     if not isinstance(bbox, BoundingBox):
         bbox = BoundingBox(bbox)
 
@@ -479,5 +521,5 @@ def plot(obj, target=None, bbox=(0, 0, 600, 600), *args, **kwds):
     # Also return the plot itself
     return result
 
-#####################################################################
 
+#####################################################################
