@@ -15,7 +15,7 @@ import re
 import tokenize
 import token
 
-__all__ = ["construct_graph_from_formula"]
+__all__ = ("construct_graph_from_formula",)
 
 __license__ = """\
 Copyright (C) 2006-2012  Tamás Nepusz <ntamas@gmail.com>
@@ -37,13 +37,14 @@ Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
 02110-1301 USA
 """
 
+
 def generate_edges(formula):
     """Parses an edge specification from the head of the given
     formula part and yields the following:
-    
+
       - startpoint(s) of the edge by vertex names
       - endpoint(s) of the edge by names or an empty list if the vertices are isolated
-      - a pair of bools to denote whether we had arrowheads at the start and end vertices 
+      - a pair of bools to denote whether we had arrowheads at the start and end vertices
     """
     if formula == "":
         yield [], [""], [False, False]
@@ -90,7 +91,10 @@ def generate_edges(formula):
                 # End markers are fine
                 pass
             else:
-                msg = "invalid token found in edge specification: %s; token_type=%r; tok=%r" % (formula, token_type, tok)
+                msg = (
+                    "invalid token found in edge specification: %s; token_type=%r; tok=%r"
+                    % (formula, token_type, tok)
+                )
                 raise SyntaxError(msg)
         else:
             # We are parsing an edge operator
@@ -111,10 +115,9 @@ def generate_edges(formula):
     yield start_names, end_names, arrowheads
 
 
-def construct_graph_from_formula(cls, formula = None, attr = "name",
-        simplify = True):
+def construct_graph_from_formula(cls, formula=None, attr="name", simplify=True):
     """Graph.Formula(formula = None, attr = "name", simplify = True)
-    
+
     Generates a graph from a graph formula
 
     A graph formula is a simple string representation of a graph.
@@ -143,7 +146,7 @@ def construct_graph_from_formula(cls, formula = None, attr = "name",
     Some simple examples:
 
       >>> from igraph import Graph
-      >>> print(Graph.Formula())           # empty graph
+      >>> print(Graph.Formula())          # empty graph
       IGRAPH UN-- 0 0 --
       + attr: name (v)
       >>> g = Graph.Formula("A-B")        # undirected graph
@@ -167,7 +170,7 @@ def construct_graph_from_formula(cls, formula = None, attr = "name",
       + attr: name (v)
       + edges (vertex names):
       A->B
-      
+
     If you have may disconnected componnets, you can separate them
     with commas. You can also specify isolated vertices:
 
@@ -199,10 +202,10 @@ def construct_graph_from_formula(cls, formula = None, attr = "name",
     @param simplify: whether the simplify the constructed graph
     @return: the constructed graph:
     """
-    
+
     # If we have no formula, return an empty graph
     if formula is None:
-        return cls(0, vertex_attrs = {attr: []})
+        return cls(0, vertex_attrs={attr: []})
 
     vertex_ids, edges, directed = UniqueIdGenerator(), [], False
     # Loop over each part in the formula
@@ -212,22 +215,19 @@ def construct_graph_from_formula(cls, formula = None, attr = "name",
         # Parse the first vertex specification from the formula
         for start_names, end_names, arrowheads in generate_edges(part):
             start_ids = [vertex_ids[name] for name in start_names]
-            end_ids   = [vertex_ids[name] for name in end_names]
+            end_ids = [vertex_ids[name] for name in end_names]
             if not arrowheads[0] and not arrowheads[1]:
                 # This is an undirected edge. Do we have a directed graph?
                 if not directed:
                     # Nope, add the edge
-                    edges.extend((id1, id2) for id1 in start_ids \
-                                 for id2 in end_ids)
+                    edges.extend((id1, id2) for id1 in start_ids for id2 in end_ids)
             else:
                 # This is a directed edge
                 directed = True
                 if arrowheads[1]:
-                    edges.extend((id1, id2) for id1 in start_ids \
-                                 for id2 in end_ids)
+                    edges.extend((id1, id2) for id1 in start_ids for id2 in end_ids)
                 if arrowheads[0]:
-                    edges.extend((id2, id1) for id1 in start_ids \
-                                 for id2 in end_ids)
+                    edges.extend((id2, id1) for id1 in start_ids for id2 in end_ids)
 
     # Grab the vertex names into a list
     vertex_attrs = {}
@@ -237,4 +237,3 @@ def construct_graph_from_formula(cls, formula = None, attr = "name",
     if simplify:
         result.simplify()
     return result
-
